==> haskell-either-4.4.1.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-6l0lf0jupinGQdYUxKNQra
key: either-4.4.1.1-6l0lf0jupinGQdYUxKNQra
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: f348fe58787705e19818ebe679a0c40b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-6l0lf0jupinGQdYUxKNQra
depends:
    MonadRandom-0.4.2.3-8TfCm6PGvGYB7omozORhov base-4.9.0.0
    bifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    free-4.12.4-LcxMyZIxIoo6h2gqXah9QK
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-CUL7kUu4nBbDVNmgOaH64k
    semigroupoids-5.1-5WI5yrkqR6b5vppUpisNlN
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1.1-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-EbNPoaWgoOPDzN8mAfWK3D
key: either-4.4.1.1-EbNPoaWgoOPDzN8mAfWK3D
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: f24712cc7b93a2608c87bd757a6b46eb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-EbNPoaWgoOPDzN8mAfWK3D
depends:
    MonadRandom-0.4.2.3-8TfCm6PGvGYB7omozORhov base-4.9.0.0
    bifunctors-5.4.1-LxooPbwcZDP8AMIXsIu3An
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    free-4.12.4-Aed7uNZqrKqF7XkiVApgap
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-5RA339bRfsXIbryi2lNqpM
    semigroupoids-5.1-DzcNuJqpBH92pXLHWsg7Nu
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
